==> apache-cxf-3.6.10-src.zip: apache-cxf-3.6.10-src/systests/uncategorized/src/test/java/org/apache/cxf/systest/mtom/Data.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.mtom;

import javax.activation.DataHandler;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlMimeType;
import javax.xml.bind.annotation.XmlType;

@XmlType(name = "Data", namespace = "http://mtom.systest.cxf.apache.org")
@XmlAccessorType(XmlAccessType.FIELD)
public class Data {

    @XmlElement(name = "someData", namespace = "http://mtom.systest.cxf.apache.org")
    @XmlMimeType("application/octet-stream")
    protected DataHandler someData;

    public DataHandler getSomeData() {
        return someData;
    }

    public void setSomeData(DataHandler someData) {
        this.someData = someData;
    }

}

==> apache-cxf-4.0.8-src.zip: apache-cxf-4.0.8-src/systests/uncategorized/src/test/java/org/apache/cxf/systest/mtom/Data.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.mtom;

import jakarta.activation.DataHandler;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlMimeType;
import jakarta.xml.bind.annotation.XmlType;

@XmlType(name = "Data", namespace = "http://mtom.systest.cxf.apache.org")
@XmlAccessorType(XmlAccessType.FIELD)
public class Data {

    @XmlElement(name = "someData", namespace = "http://mtom.systest.cxf.apache.org")
    @XmlMimeType("application/octet-stream")
    protected DataHandler someData;

    public DataHandler getSomeData() {
        return someData;
    }

    public void setSomeData(DataHandler someData) {
        this.someData = someData;
    }

}
